@@ -1,16 +1,17 @@
 from flask import Flask, request
+from flask_cors import CORS
 import os
-from os.path import exists
 from command.initialize import Initialize
 from command.collect import Collect
 from command.prepare import Prepare
 app=Flask(__name__)
+CORS(app)
 
 @app.route('/')
 def root_route():
     return 'Hello World'
 
-@app.route('/initialize', methods=['POST'])
+@app.route('/newPost', methods=['POST'])
 def initialize():
     input=request.json
 
@@ -23,6 +24,7 @@ def initialize():
     initialize_command.check_identity()
     initialize_command.send_request_to_s3()
     requestID=initialize_command.make_request()
+    print('The requestID is:', requestID)
     initialize_command.print_class_parameter()
 
     # get the region
@@ -104,51 +106,12 @@ def initialize():
         if(i==len(regions)-1):
             prepare_command.exportToJSON()
             prepare_command.export_JSON_to_S3()
-            prepare_command.write_to_dynamoDB(requestID)
+            prepare_command.write_to_dynamoDB(str(requestID))
     return {  
         'status': 'Success',
         'code': 200,
         'message': 'Succeed initializing credentials'
     }
-@app.route('/collect', methods=['POST'])
-def collectMetadata():
-
-    # data = request.get_json()
-    try:
-        os.system('python ./command/collect.py')  
-    except:
-        return{
-            'status': 'Error',
-            'code': 500,
-            'message':'Bad Request Error'
-        }
-
-
-    return {  
-        'status': 'Success',
-        'code': 200,
-        'message': 'Succeed collecting metadata'
-    }
-
-@app.route('/prepare',methods=['POST'])
-def prepareJSONFile():
-    try:
-        os.system('./job2.sh')
-        if(not exists('./data/data.json')):
-            raise Exception('No JSON file exist')
-    except Exception as e:
-        return{
-            'status': 'Error',
-            'code': 500,
-            'message':'Bad Request Error',
-            'detail': str(e)
-        }
-
-    return {  
-        'status': 'Success',
-        'code': 200,
-        'message': 'Succeed prepare JSON file'
-    }
 
 @app.route('/request',methods=['DELETE'])
 def clearJSONMetadata():
