@@ -2,6 +2,7 @@ import boto3
 import os
 import uuid
 import datetime
+import pytz
 
 object_name='data-'+str(uuid.uuid4())+'.json'
 
@@ -19,14 +20,22 @@ def upload_to_S3(region):
 
 def write_to_dynamo_db(region,requestID):
     client=boto3.client('dynamodb',region_name=region)
-    item_dict={
-        'status': {'S':'COMPLETED'},
-        'data_name': {'S':object_name},
-        'timestamp': {'S':str(datetime.datetime.now())}
-    }
-    
+    date=datetime.datetime.now()
+    # create taipei timezone
+    tw=pytz.timezone('Asia/Taipei')
+    twDate=tw.localize(date)
     client.update_item(TableName='architectureDB',
     Key={
         'requestID':{'S':requestID}
     },
-    AttributeUpdates=item_dict)
+    UpdateExpression="SET #attr1 = :var1, #attr2 = :var2,#attr3 = :var3",
+    ExpressionAttributeNames={
+        '#attr1': 'status',
+        '#attr2':'data_name',
+        '#attr3':'timestamp'
+    },
+    ExpressionAttributeValues={
+            ':var1': {'S':'COMPLETED'},
+            ':var2': {'S':object_name},
+            ':var3': {'S':str(twDate)}
+            })
